#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['measuregreencode']

package_data = \
{'': ['*']}

setup(name='measuregreencode',
      version='1.1.0',
      description='This is the documentation for the package. ',
      author='David Harris',
      author_email='d_h449@txstate.edu',
      url='https://git.txstate.edu/d-h449/measure',
      packages=packages,
      package_data=package_data,
     )
